@@ -64,8 +64,7 @@ The most commonly used {self.CLI_NAME} commands are:
         args = sys.argv[2:]
         add_tags.main(args)
 
-
-    def lookup_threat(self):
+    def lookup_threats(self):
         args = sys.argv[2:]
         lookup_threats.main(args)
 
