@@ -3,7 +3,7 @@ from collections import OrderedDict
 
 from datalake_scripts.common.base_script import BaseScripts
 from datalake_scripts.common.logger import logger
-from datalake_scripts.engines.post_engine import ThreatsScoringPost, AddThreatsPost
+from datalake_scripts.engines.post_engine import ScorePost, ThreatsPost
 
 
 def main(override_args=None):
@@ -28,6 +28,12 @@ def main(override_args=None):
         nargs='+',
         help='Choose specific threat types and their score, like: ddos 50 scam 15.',
     )
+    parser.add_argument(
+        '-w',
+        '--whitelist',
+        help='Whitelist the input, equivalent to setting all threat types at 0.',
+        action='store_true',
+    )
     parser.add_argument(
         '--permanent',
         help='''Permanent: all values will override any values provided by both newer and
@@ -46,18 +52,20 @@ def main(override_args=None):
     if not args.hashkeys and not args.input_file:
         parser.error("either a hashkey or an input_file is required")
 
-    if not args.threat_types or len(args.threat_types) % 2 != 0:
-        parser.error("threat_types invalid ! should be like: ddos 50 scam 15")
-    parsed_threat_type = AddThreatsPost.parse_threat_types(args.threat_types)
+    if args.whitelist:
+        parsed_threat_type = ThreatsPost.get_whitelist_threat_types()
+    else:
+        if not args.threat_types or len(args.threat_types) % 2 != 0:
+            parser.error("threat_types invalid ! should be like: ddos 50 scam 15")
+        parsed_threat_type = ThreatsPost.parse_threat_types(args.threat_types)
     # removing duplicates while preserving order
     hashkeys = args.hashkeys
     if args.input_file:
         retrieve_hashkeys_from_file(args.input_file, hashkeys)
     hashkeys = list(OrderedDict.fromkeys(hashkeys)) if hashkeys else []
     # Load api_endpoints and tokens
-    endpoint_url, main_url, tokens = starter.load_config(args)
-    url_threats = main_url + endpoint_url['endpoints']['threats']
-    post_engine_edit_score = ThreatsScoringPost(url_threats, main_url, tokens)
+    endpoint_config, main_url, tokens = starter.load_config(args)
+    post_engine_edit_score = ScorePost(endpoint_config, args.env, tokens)
 
     response_dict = post_engine_edit_score.post_new_score_from_list(
         hashkeys,
